# Coming from R

tbd...
| pymer4 code | R code | Description |
|--------|---|-------------|
| `lm()` | `lm()` | Fits linear models using ordinary least squares |
| `glm()` | `glm()` | Fits generalized linear models using maximum likelihood estimation |
| `lmer()` | `lmer()` | Fits linear mixed effects models using restricted maximum likelihood |

## Creating a model

## Fitting a model

## Summarizing a model

## Marginal effects

## Prediction & cross-validation